﻿using System.Collections.ObjectModel;
using BookShelf.Web.Models;
using Papa.Common;
using MEFedMVVM.ViewModelLocator;
using System.ComponentModel.Composition;

namespace BookShelf
{
    [ExportViewModel("Checkout")]
    public class CheckoutViewModel : ViewModel
    {
        protected IPageConductor PageConductor { get; set; }
        protected IBookDataService BookDataService { get; set; }
     
        [ImportingConstructor]
        public CheckoutViewModel(
            IPageConductor pageConductor,
            IBookDataService bookDataService)
        {
            PageConductor = pageConductor;
            BookDataService = bookDataService;
            BookDataService.NotifyHasChanges += BookDataService_NotifyHasChanges;

            InitializeModels();
            RegisterCommands();
            LoadData();
        }

        private void InitializeModels()
        {
            Checkouts = new ObservableCollection<Checkout>();
            SelectedCheckout = new Checkout();
        }

        private void BookDataService_NotifyHasChanges(object sender, HasChangesEventArgs e)
        {
            HasChanges = e.HasChanges;
            //SaveCheckoutCommand.RaiseCanExecuteChanged();
        }

        protected override void RegisterCommands()
        {
            //SaveCheckoutCommand = new RelayCommand(OnSaveBook, () => HasChanges);
        }

        //private void OnSaveCheckout()
        //{
        //    BookDataService.Save(submitCallback, null);
        //}

        //private void submitCallback(SubmitOperation op)
        //{
        //    string msg = op.HasError ? "Save was unsuccessful" : "Save was successful";
        //    var dialogMessage = new SavedCheckoutDialogMessage(msg, "Save");
        //    Messenger.Default.Send(dialogMessage);
        //}

        public override void LoadData()
        {
            LoadCheckouts();
        }

        private void LoadCheckouts()
        {
            Checkouts.Clear();
            BookDataService.GetCheckouts(GetCheckoutsCallback);
        }

        private void GetCheckoutsCallback(ObservableCollection<Checkout> checkouts)
        {
            if (checkouts != null)
            {
                Checkouts = checkouts;
                if (Checkouts.Count > 0)
                {
                    SelectedCheckout = Checkouts[0];
                }

            }
        }

        private bool _hasChanges;
        public bool HasChanges
        {
            get { return _hasChanges; }
            set
            {
                _hasChanges = value;
                RaisePropertyChanged("HasChanges");
            }
        }

        private ObservableCollection<Checkout> _checkouts;
        public ObservableCollection<Checkout> Checkouts
        {
            get { return _checkouts; }
            set
            {
                _checkouts = value;
                RaisePropertyChanged("Checkouts");
            }
        }

        private Checkout _selectedCheckout;
        public Checkout SelectedCheckout
        {
            get { return _selectedCheckout; }
            set
            {
                _selectedCheckout = value;
                RaisePropertyChanged("SelectedCheckout");
            }
        }
    }
}